@@ -7,6 +7,7 @@ __all__ = ['getConfig']
 
 defaultConfig = {
     'LOGGING.level': 'ERROR',
+    'LOGGING.print_file': False,
     'LOGIN.cookieFile': '.cookies',
     'LOGIN.envFile': '.env',
     # 密钥
@@ -20,9 +21,13 @@ def getConfig(name, file='config.ini', default={}):
     cfg.read(configPwd, encoding='utf-8')
     def getval(key):
         if cfg.has_option(name, key):
-            return cfg.get(name, key)
+            ans = cfg.get(name, key)
+            if ans in ['True', 'False']: ans = eval(ans)
+            return ans;
         return default.get(key) or defaultConfig.get('.'.join([name, key]))
     return getval
 
 if __name__ == "__main__":
-    print(getConfig('CRYPTO')('key'))
+    ans = getConfig('LOGGING')('print_file')
+    print(ans)
+    print(type(ans))
